xcore: use strcpy() rather than strncpy()
diff --git a/arch/XCore/XCoreInstPrinter.c b/arch/XCore/XCoreInstPrinter.c
index b71ae8e..ad2f169 100644
--- a/arch/XCore/XCoreInstPrinter.c
+++ b/arch/XCore/XCoreInstPrinter.c
@@ -46,12 +46,12 @@
 	char *p, *p2;
 	char tmp[128];
 
 // make MSVC shutup on strncpy()
 #ifdef _MSC_VER
 #pragma warning(push)
 #pragma warning(disable : 4996)
 #endif
-	strncpy(tmp, code, strlen(code)); // safe because code is way shorter than 128 bytes
+	strcpy(tmp, code); // safe because code is way shorter than 128 bytes
 #ifdef _MSC_VER
 #pragma warning(pop)
 #endif
@@ -46,12 +46,12 @@
 	char tmp[128];
 
-// make MSVC shutup on strncpy()
+// make MSVC shut up on strcpy()
 #ifdef _MSC_VER
 #pragma warning(push)